@@ -1,17 +1,16 @@
 package X11::IdleTime;
 
 use strict;
-use warnings;
 
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(GetIdleTime);
-$VERSION = '0.08';
+$VERSION = '0.01';
 
 use Inline (
 	C => 'DATA',
-	VERSION => '0.08',
+	VERSION => '0.03',
 	NAME => 'X11::IdleTime',
 	LIBS => '-L/usr/X11R6/lib/ -lX11 -lXext -lXss',
 	);
@@ -40,11 +39,11 @@ The X11::IdleTime module is useful for checking how long the user has been idle.
 
 =head1 AUTHOR
 
-Adam Wendt <thelsdj@gmail.com> (http://blog.thelsdj.org/)
+Adam Wendt <adam@ipwebdev.com> (http://ipwebdev.com/weblog/)
 
 =head1 COPYRIGHT
 
-Copyright 2003-2008 Adam Wendt <thelsdj@gmail.com>
+Copyright 2003-2005 Adam Wendt <adam@ipwebdev.com>
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
@@ -67,8 +66,8 @@ int GetIdleTime () {
         if((display=XOpenDisplay(NULL)) == NULL) { return(-1); }
         screen = DefaultScreen(display);
         XScreenSaverQueryInfo(display, RootWindow(display,screen), mit_info);
+	XFree(mit_info);
+	XCloseDisplay(display); 
         idle_time = (mit_info->idle) / 1000;
-        XFree(mit_info);
-        XCloseDisplay(display); 
         return idle_time;
 }
